/***********************************************************************
*
* Copyright (c) 2021-2023 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   QComboBox *localeCombo;

   QLineEdit *currency;
   QLineEdit *number;
   QLineEdit *firstDay;
   QLineEdit *dateLong;
   QLineEdit *dateShort;

   void localeChanged(int index);
};

MainWindow::MainWindow()
{
   setMinimumSize(600, 400);

   QLabel *localeLabel = new QLabel("Select Locale Setting:");

   QLocale de(QLocale::German,   QLocale::Germany);
   QLocale us(QLocale::English,  QLocale::UnitedStates);
   QLocale uk(QLocale::English,  QLocale::UnitedKingdom);
   QLocale fr(QLocale::French,   QLocale::France);
   QLocale in(QLocale::Hindi,    QLocale::India);
   QLocale pe(QLocale::Spanish,  QLocale::Peru);
   QLocale es(QLocale::Spanish,  QLocale::Spain);
   QLocale jp(QLocale::Japanese, QLocale::Japan);

   localeCombo = new QComboBox;
   localeCombo->addItem("German/Germany",        de);
   localeCombo->addItem("English/UnitedStates",  us);
   localeCombo->addItem("English/UnitedKingdom", uk);
   localeCombo->addItem("French/France",         fr);
   localeCombo->addItem("Hindi/India",           in);
   localeCombo->addItem("Spanish/Peru",          pe);
   localeCombo->addItem("Spanish/Spain",         es);
   localeCombo->addItem("Japanese/Japan",        jp);

   QLabel *currencyLabel  = new QLabel("Currency with Symbol: ");
   QLabel *numberLabel    = new QLabel("Floating Point Number:");
   QLabel *firstDayLabel  = new QLabel("First Day Of Week:");
   QLabel *dateLongLabel  = new QLabel("Long Date Format");
   QLabel *dateShortLabel = new QLabel("Short Date Format");

   currency = new QLineEdit();
   currency->setReadOnly(true);

   number = new QLineEdit();
   number->setReadOnly(true);

   firstDay = new QLineEdit();
   firstDay->setReadOnly(true);

   dateLong = new QLineEdit();
   dateLong->setReadOnly(true);

   dateShort = new QLineEdit();
   dateShort->setReadOnly(true);

   QPushButton *pb_1 = new QPushButton();
   pb_1->setText("Close");

   QGridLayout *grid1 = new QGridLayout();
   grid1->setVerticalSpacing(15);

   grid1->addWidget(localeLabel, 1, 1);
   grid1->addWidget(localeCombo, 1, 2, 1, 3);

   grid1->addItem(new QSpacerItem(200, 35,
      QSizePolicy::Fixed, QSizePolicy::Fixed), 2, 3);

   grid1->addWidget(currencyLabel, 3, 1);
   grid1->addWidget(currency, 3, 2);

   grid1->addWidget(numberLabel, 5, 1);
   grid1->addWidget(number, 5, 2);

   grid1->addWidget(firstDayLabel, 7, 1);
   grid1->addWidget(firstDay, 7, 2);

   grid1->addWidget(dateLongLabel, 9, 1);
   grid1->addWidget(dateLong, 9, 2);

   grid1->addWidget(dateShortLabel, 11, 1);
   grid1->addWidget(dateShort, 11, 2);

   grid1->addItem(new QSpacerItem(0, 0,
      QSizePolicy::Expanding, QSizePolicy::Expanding), 13, 3);

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addStretch();
   layout1->addWidget(pb_1);
   layout1->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->setContentsMargins(30, 40, 30, 15);
   layoutMain->addLayout(grid1);
   layoutMain->addLayout(layout1);

   connect(localeCombo, cs_mp_cast<int>(&QComboBox::currentIndexChanged),
      this, &MainWindow::localeChanged);

   connect(pb_1, &QPushButton::clicked, this, &QWidget::close);

   localeCombo->setCurrentIndex(1);
   this->localeChanged(localeCombo->currentIndex());
}

void MainWindow::localeChanged(int index)
{
   QLocale locale = localeCombo->itemData(index).toLocale();

   currency->setText(locale.toCurrencyString(130729.47));
   number->setText(locale.toString(12345678.90, 'f', 2));

   Qt::DayOfWeek dow = locale.firstDayOfWeek();
   firstDay->setText(locale.dayName(dow));

   dateLong->setText(locale.toString(QDate::currentDate(),  QLocale::LongFormat));
   dateShort->setText(locale.toString(QDate::currentDate(), QLocale::ShortFormat));
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

